use std::process::Command;

fn main() {
    try_pkg_config();
}

fn try_pkg_config() {
    let mut cfg = pkg_config::Config::new();
    cfg.cargo_metadata(false);
    let lib = cfg.probe("libcurl").unwrap();

    if cfg!(feature = "http2") && !curl_config_reports_http2() {
        panic!("System libcurl was built without HTTP/2 support.");
    }

    cfg.cargo_metadata(true).probe("libcurl").unwrap();
    for path in lib.include_paths.iter() {
        println!("cargo:include={}", path.display());
    }
}

fn curl_config_reports_http2() -> bool {
    let output = Command::new("curl-config").arg("--features").output().unwrap();
    if !output.status.success() {
        println!("curl-config failed: {}", output.status);
        return false;
    }
    let stdout = String::from_utf8_lossy(&output.stdout);
    if !stdout.contains("HTTP2") {
        return false;
    }
    true
}
